pub trait DistinctOnDsl<Selection> {
type Output;
// Required method
fn distinct_on(self, selection: Selection) -> DistinctOn<Self, Selection>;
}Available on crate feature
postgres_backend only.Expand description
The distinct_on method
This trait should not be relied on directly by most apps. Its behavior is
provided by QueryDsl. However, you may need a where clause on this trait
to call distinct_on from generic code.
Required Associated Types
Required Methods
Sourcefn distinct_on(self, selection: Selection) -> DistinctOn<Self, Selection>
fn distinct_on(self, selection: Selection) -> DistinctOn<Self, Selection>
See the trait documentation
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".