pub trait FindDsl<PK> {
type Output;
// Required method
fn find(self, id: PK) -> Self::Output;
}Expand description
The find method
This trait should not be relied on directly by most apps. Its behavior is
provided by QueryDsl. However, you may need a where clause on this trait
to call find from generic code.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".