pub trait LimitDsl<DummyArgForAutoType = i64> {
type Output;
// Required method
fn limit(self, limit: i64) -> Self::Output;
}Expand description
The limit method
This trait should not be relied on directly by most apps. Its behavior is
provided by QueryDsl. However, you may need a where clause on this trait
to call limit from generic code.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".