pub trait OrFilterDsl<Predicate> {
type Output;
// Required method
fn or_filter(self, predicate: Predicate) -> Self::Output;
}Expand description
The or_filter method
This trait should not be relied on directly by most apps. Its behavior is
provided by QueryDsl. However, you may need a where clause on this trait
to call or_filter from generic code.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".